@@ -134,7 +134,7 @@ MainWindow::initLogging ()
                         this     , SLOT(onCleanupLogsArray()));
     Q_ASSERT(rv); Q_UNUSED(rv);
 
-    setStatus("Using qgvdial version 0.3.863");
+    setStatus("Using qgvdial version 0.3.866");
 }//MainWindow::initLogging
 
 /** Log information to console and to log file
@@ -2222,6 +2222,7 @@ MainWindow::onGetLogLocation(bool success, const QByteArray &response,
             break;
         }
 
+        //- Collect all the parameters I want to send to myself -//
         QDateTime dtNow = QDateTime::currentDateTime().toUTC();
         token->inParams["date"] = dtNow;
 
@@ -2229,7 +2230,6 @@ MainWindow::onGetLogLocation(bool success, const QByteArray &response,
         QDomElement root = doc.createElement("Logs");
         doc.appendChild(root);
 
-
         QDomElement paramsTag = doc.createElement("Params");
         root.appendChild(paramsTag);
 
@@ -2242,7 +2242,7 @@ MainWindow::onGetLogLocation(bool success, const QByteArray &response,
         QDomElement appVerTag = doc.createElement("Version");
         paramsTag.appendChild(appVerTag);
 
-        QDomText appVerText = doc.createTextNode("0.3.863");
+        QDomText appVerText = doc.createTextNode("0.3.866");
         appVerTag.appendChild(appVerText);
 
         QDomElement osVerTag = doc.createElement("OsVer");
@@ -2252,6 +2252,10 @@ MainWindow::onGetLogLocation(bool success, const QByteArray &response,
         QDomText osVerText = doc.createTextNode(osd.getOSDetails());
         osVerTag.appendChild(osVerText);
 
+        // Flush the logs before trying to send them.
+        qgv_LogFlush();
+
+        // Put all the logs into the XML.
         for (int i = arrLogFiles.count(); i > 0; i--) {
             QFile fLog(arrLogFiles[i-1]);
             if (!fLog.open (QIODevice::ReadOnly)) {
@@ -2265,6 +2269,7 @@ MainWindow::onGetLogLocation(bool success, const QByteArray &response,
             oneLogFile.appendChild(t);
         }
 
+        // Post the logs to my server
         QString postLocation = response;
         QUrl url(postLocation);
         QNetworkRequest req(url);
@@ -2294,6 +2299,7 @@ MainWindow::onLogPosted(bool success, const QByteArray &response,
             break;
         }
 
+        // The logs have been posted. Now send an email to me about it.
         QString strReply = response;
 
         QUrl url("mailto:yuvraaj@gmail.com");
@@ -2303,7 +2309,7 @@ MainWindow::onLogPosted(bool success, const QByteArray &response,
         QDateTime dt = token->inParams["date"].toDateTime();
         QString body = QString("Logs captured at %1 \n")
                                 .arg (dt.toUTC ().toString (Qt::ISODate));
-        body += "qgvdial version = 0.3.863 \n";
+        body += "qgvdial version = 0.3.866 \n";
         body += QString("OS: %1 \n").arg(osd.getOSDetails());
         body += QString("Logs are in %1 \n").arg(strReply);
         url.addQueryItem ("body", body);
