@@ -199,11 +199,21 @@ private slots:
     //! Invoked when the desktop is resized (useful only on mobile platforms)
     void onDesktopResized();
 
+    //! When the user needs to send me logs
+    void onSigSendLogs();
+    //! When the server responds with the location to post the logs
+    void onGetLogLocation(bool success, const QByteArray &response,
+                          QNetworkReply *reply, void *ctx);
+    //! When the server responds once I've sent the logs
+    void onLogPosted(bool success, const QByteArray &response,
+                     QNetworkReply *reply, void *ctx);
+
 private:
     void initLogging ();
 
     //! Initialize the QML view
     void initQML ();
+    bool connectSettingsSignals();
 
     void initContacts ();
     void deinitContacts ();
@@ -240,6 +250,8 @@ private:
 
     QObject * getQMLObject(const char *pageName);
 
+    bool ensureNwMgr();
+
 private:
     GVApi           gvApi;
 
@@ -251,8 +263,12 @@ private:
     //! GV Inbox object
     GVInbox         oInbox;
 
+    //! The Phonon vmail player
     Phonon::MediaObject *vmailPlayer;
 
+    //! The QNAM for the MainWindow. Almost never used except to send logs.
+    QNetworkAccessManager *nwMgr;
+
     //! Timer for status messages
     QTimer          statusTimer;
 
